@@ -6,6 +6,7 @@
 #
 #  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
 import asyncio
+import shlex
 import traceback
 from dataclasses import dataclass, field
 from typing import Literal, Any
@@ -24,7 +25,9 @@ class RunResult:
 
 async def execute_code_block(code: str, language: str, timeout: float = 1) -> RunResult:
     if language == 'python':
-        process_args = ['python', '-c', code]
+        # process_args = ['script', '-q', '-c', 'python', '-c', code]
+        process_args = ['script', '-q', '-c', f"python -c {shlex.quote(code)}"]
+        # process_args = ['python', '-c', code]
     elif language in ('shell', 'bash', 'sh'):
         process_args = ['script', '-q', '-c', code]
     else:
